@@ -32,3 +32,26 @@ def test_low_version(api_low_version):
 @pytest.mark.vcr()
 def test_emoji(api):
     assert len(api.custom_emojis()) == 0
+
+@pytest.mark.vcr()
+def test_health(api):
+    assert api.instance_health() == True
+    
+@pytest.mark.vcr()
+def test_nodeinfo(api):
+    nodeinfo = api.instance_nodeinfo()
+    assert nodeinfo
+    assert nodeinfo.version == '2.0'
+    
+@pytest.mark.vcr()
+def test_trends(api):
+    assert isinstance(api.trends(), list)
+    
+@pytest.mark.vcr()
+def test_directory(api):
+    directory = api.directory()
+    assert directory
+    assert isinstance(directory, list)
+    assert len(directory) > 0
+
+    
